@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2009-2012  Jeremy Monnet
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 from woob.capabilities.library import CapBook, Book
 from woob.tools.application.repl import ReplApplication
 from woob.tools.application.formatters.iformatter import PrettyFormatter
@@ -32,15 +28,15 @@ class RentedListFormatter(PrettyFormatter):
     RED = '[1;31m'
 
     def get_title(self, obj):
-        s = u'%s — %s (%s)' % (obj.author, obj.name, obj.date)
+        s = '%s — %s (%s)' % (obj.author, obj.name, obj.date)
         if obj.late:
-            s += u' %sLATE!%s' % (self.RED, self.NC)
+            s += ' %sLATE!%s' % (self.RED, self.NC)
         return s
 
 
 class AppBooks(ReplApplication):
     APPNAME = 'books'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2012-YEAR Jeremy Monnet'
     CAPS = CapBook
     DESCRIPTION = "Console application allowing to list your books rented or booked at the library, " \
