@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2013 Julien Veyssier
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 from datetime import datetime
 
 from woob.applications.torrent.torrent import TorrentInfoFormatter, TorrentListFormatter
@@ -43,7 +39,7 @@ class MovieInfoFormatter(IFormatter):
                         'other_titles', 'duration', 'pitch', 'note', 'roles', 'country')
 
     def format_obj(self, obj, alias):
-        result = u'%s%s%s\n' % (self.BOLD, obj.original_title, self.NC)
+        result = '%s%s%s\n' % (self.BOLD, obj.original_title, self.NC)
         result += 'ID: %s\n' % obj.fullid
         if not empty(obj.release_date):
             result += 'Released: %s\n' % obj.release_date.strftime('%Y-%m-%d')
@@ -78,7 +74,7 @@ class MovieListFormatter(PrettyFormatter):
         return obj.original_title
 
     def get_description(self, obj):
-        result = u''
+        result = ''
         if not empty(obj.short_description):
             result = obj.short_description
         return result
@@ -88,10 +84,10 @@ class MovieReleasesFormatter(PrettyFormatter):
     MANDATORY_FIELDS = ('id', 'original_title', 'all_release_dates')
 
     def get_title(self, obj):
-        return u'Releases of %s' % obj.original_title
+        return 'Releases of %s' % obj.original_title
 
     def get_description(self, obj):
-        return u'\n%s' % obj.all_release_dates
+        return '\n%s' % obj.all_release_dates
 
 
 def yearsago(years, from_date=None):
@@ -120,7 +116,7 @@ class PersonInfoFormatter(IFormatter):
     MANDATORY_FIELDS = ('id', 'name', 'birth_date', 'birth_place', 'short_biography')
 
     def format_obj(self, obj, alias):
-        result = u'%s%s%s\n' % (self.BOLD, obj.name, self.NC)
+        result = '%s%s%s\n' % (self.BOLD, obj.name, self.NC)
         result += 'ID: %s\n' % obj.fullid
         if not empty(obj.real_name):
             result += 'Real name: %s\n' % obj.real_name
@@ -157,7 +153,7 @@ class PersonListFormatter(PrettyFormatter):
         return obj.name
 
     def get_description(self, obj):
-        result = u''
+        result = ''
         if not empty(obj.short_description):
             result = obj.short_description
         return result
@@ -167,16 +163,16 @@ class PersonBiographyFormatter(PrettyFormatter):
     MANDATORY_FIELDS = ('id', 'name', 'biography')
 
     def get_title(self, obj):
-        return u'Biography of %s' % obj.name
+        return 'Biography of %s' % obj.name
 
     def get_description(self, obj):
-        result = u'\n%s' % obj.biography
+        result = '\n%s' % obj.biography
         return result
 
 
 class AppCinema(ReplApplication):
     APPNAME = 'cinema'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2013-YEAR Julien Veyssier'
     DESCRIPTION = "Console application allowing to search for movies and persons on various cinema databases " \
                   ", list persons related to a movie, list movies related to a person and list common movies " \
@@ -350,7 +346,7 @@ class AppCinema(ReplApplication):
 
         Search movies.
         """
-        self.change_path([u'search movies'])
+        self.change_path(['search movies'])
         if not pattern:
             pattern = None
 
@@ -365,7 +361,7 @@ class AppCinema(ReplApplication):
 
         Search persons.
         """
-        self.change_path([u'search persons'])
+        self.change_path(['search persons'])
         if not pattern:
             pattern = None
 
@@ -445,7 +441,7 @@ class AppCinema(ReplApplication):
         # i would like to clarify with fillobj but how could i fill the movie AND choose the country ?
         for release in self.do('get_movie_releases', movie.id, country, caps=CapCinema, backends=movie.backend):
             if not empty(release):
-                movie.all_release_dates = u'%s' % (release)
+                movie.all_release_dates = '%s' % (release)
             else:
                 print('Movie releases not found for %s' % movie.original_title, file=self.stderr)
                 return 3
@@ -512,9 +508,9 @@ class AppCinema(ReplApplication):
         except CallErrors as errors:
             for backend, error, backtrace in errors:
                 if isinstance(error, MagnetOnly):
-                    print(u'Error(%s): No direct URL available, '
-                          u'please provide this magnet URL '
-                          u'to your client:\n%s' % (backend, error.magnet), file=self.stderr)
+                    print('Error(%s): No direct URL available, '
+                          'please provide this magnet URL '
+                          'to your client:\n%s' % (backend, error.magnet), file=self.stderr)
                     return 4
                 else:
                     self.bcall_error_handler(backend, error, backtrace)
@@ -529,7 +525,7 @@ class AppCinema(ReplApplication):
 
         Search torrents.
         """
-        self.change_path([u'search torrent'])
+        self.change_path(['search torrent'])
         if not pattern:
             pattern = None
 
@@ -551,7 +547,7 @@ class AppCinema(ReplApplication):
 
         pattern = movie.original_title
 
-        self.change_path([u'search torrent'])
+        self.change_path(['search torrent'])
         if not pattern:
             pattern = None
 
@@ -647,7 +643,7 @@ class AppCinema(ReplApplication):
         ----------------------
         """
         language, pattern = self.parse_command_args(line, 2, 1)
-        self.change_path([u'search subtitle'])
+        self.change_path(['search subtitle'])
         if not pattern:
             pattern = None
 
@@ -689,7 +685,7 @@ class AppCinema(ReplApplication):
             return 3
 
         pattern = movie.original_title
-        self.change_path([u'search subtitle'])
+        self.change_path(['search subtitle'])
         if not pattern:
             pattern = None
 
