@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2011 Romain Bignon
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 import os
 import tempfile
 import shlex
@@ -35,7 +31,7 @@ __all__ = ['AppContentEdit']
 
 class AppContentEdit(ReplApplication):
     APPNAME = 'contentedit'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Romain Bignon'
     DESCRIPTION = "Console application allowing to display and edit contents on various websites."
     SHORT_DESCRIPTION = "manage websites content"
