@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2012 Romain Bignon
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 from copy import copy
 
 from woob.core import CallErrors
@@ -34,9 +30,9 @@ class EventListFormatter(PrettyFormatter):
     MANDATORY_FIELDS = ('date', 'type')
 
     def get_title(self, event):
-        s = u'(%s) %s' % (event.date, event.type)
+        s = '(%s) %s' % (event.date, event.type)
         if hasattr(event, 'contact') and event.contact:
-            s += u' — %s (%s)' % (event.contact.name, event.contact.id)
+            s += ' — %s (%s)' % (event.contact.name, event.contact.id)
 
         return s
 
@@ -47,7 +43,7 @@ class EventListFormatter(PrettyFormatter):
 
 class AppDating(AppMsg):
     APPNAME = 'dating'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Romain Bignon'
     DESCRIPTION = "Console application allowing to interact with various dating websites " \
                   "and to optimize seduction algorithmically."
@@ -159,7 +155,7 @@ class AppDating(AppMsg):
             except CallErrors as errors:
                 for backend, error, backtrace in errors:
                     if isinstance(error, OptimizationNotFound):
-                        self.logger.error(u'Error(%s): Optimization "%s" not found' % (backend.name, optim_name))
+                        self.logger.error('Error(%s): Optimization "%s" not found' % (backend.name, optim_name))
                     else:
                         self.bcall_error_handler(backend, error, backtrace)
             if store:
@@ -254,7 +250,7 @@ class AppDating(AppMsg):
 
         Display dating events.
         """
-        self.change_path([u'events'])
+        self.change_path(['events'])
         self.start_format()
         for event in self.do('iter_events'):
             self.cached_format(event)
