@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2012 Romain Bignon
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 from woob.capabilities.housing import (CapHousing, Query, POSTS_TYPES,
                                          ADVERT_TYPES, HOUSE_TYPES)
 from woob.capabilities.base import empty
@@ -34,21 +30,21 @@ class HousingFormatter(IFormatter):
     MANDATORY_FIELDS = ('id', 'title', 'cost', 'currency', 'area', 'date', 'text')
 
     def format_obj(self, obj, alias):
-        result = u'%s%s%s\n' % (self.BOLD, obj.title, self.NC)
+        result = '%s%s%s\n' % (self.BOLD, obj.title, self.NC)
         result += 'ID: %s\n' % obj.fullid
 
         if hasattr(obj, 'url') and obj.url:
             result += 'URL: %s\n' % obj.url
 
         result += 'Cost: %s%s %s\n' % (obj.cost, obj.currency, obj.utilities)
-        area = u'%.2fm²' % (obj.area) if obj.area else u'%s' % obj.area
-        result += u'Area: %s\n' % area
+        area = '%.2fm²' % (obj.area) if obj.area else '%s' % obj.area
+        result += 'Area: %s\n' % area
         if hasattr(obj, 'price_per_meter') and not empty(obj.price_per_meter):
-            result += u'Price per square meter: %.2f %s/m²\n' % (obj.price_per_meter, obj.currency)
+            result += 'Price per square meter: %.2f %s/m²\n' % (obj.price_per_meter, obj.currency)
         if hasattr(obj, 'rooms') and not empty(obj.rooms):
-            result += u'Rooms: %d\n' % (obj.rooms)
+            result += 'Rooms: %d\n' % (obj.rooms)
         if hasattr(obj, 'bedrooms') and not empty(obj.bedrooms):
-            result += u'Bedrooms: %d\n' % (obj.bedrooms)
+            result += 'Bedrooms: %d\n' % (obj.bedrooms)
         if obj.date:
             result += 'Date: %s\n' % obj.date.strftime('%Y-%m-%d')
         result += 'Phone: %s\n' % obj.phone
@@ -80,7 +76,7 @@ class HousingListFormatter(PrettyFormatter):
         return '%s%s %s - %s' % (obj.cost, obj.currency, obj.utilities, obj.title)
 
     def get_description(self, obj):
-        result = u''
+        result = ''
         if hasattr(obj, 'date') and obj.date:
             result += '%s - ' % obj.date.strftime('%Y-%m-%d')
         result += obj.text
@@ -89,7 +85,7 @@ class HousingListFormatter(PrettyFormatter):
 
 class AppHousing(ReplApplication):
     APPNAME = 'housing'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2012-YEAR Romain Bignon'
     DESCRIPTION = "Console application to search for housing."
     SHORT_DESCRIPTION = "search for housing"
@@ -142,7 +138,7 @@ class AppHousing(ReplApplication):
             while r != '':
                 for i, city in enumerate(cities):
                     print('  %s%2d)%s [%s] %s (%s)' % (self.BOLD, i+1, self.NC, 'x' if city in query.cities else ' ', city.name, city.backend))
-                r = self.ask('Select cities (or empty to stop)', regexp='(\d+|)', default='')
+                r = self.ask('Select cities (or empty to stop)', regexp=r'(\d+|)', default='')
                 if not r.isdigit():
                     continue
                 r = int(r)
@@ -161,7 +157,7 @@ class AppHousing(ReplApplication):
                                               i,
                                               self.NC,
                                               'x' if good in query.house_types else ' ', good))
-            r = self.ask('Select type of house (or empty to stop)', regexp='(\d+|)', default='')
+            r = self.ask('Select type of house (or empty to stop)', regexp=r'(\d+|)', default='')
             if not r.isdigit():
                 continue
             r = int(r)
@@ -192,7 +188,7 @@ class AppHousing(ReplApplication):
                                               i,
                                               self.NC,
                                               'x' if good in query.advert_types else ' ', good))
-            r = self.ask('Select type of posts (or empty to stop)', regexp='(\d+|)', default='')
+            r = self.ask('Select type of posts (or empty to stop)', regexp=r'(\d+|)', default='')
             if not r.isdigit():
                 continue
             r = int(r)
@@ -220,13 +216,13 @@ class AppHousing(ReplApplication):
         self.complete_search(query)
 
     def complete_search(self, query):
-        self.change_path([u'housings'])
+        self.change_path(['housings'])
         self.start_format()
         for housing in self.do('search_housings', query):
             self.cached_format(housing)
 
     def ask_int(self, txt):
-        r = self.ask(txt, default='', regexp='(\d+|)')
+        r = self.ask(txt, default='', regexp=r'(\d+|)')
         if r:
             return int(r)
         return None
