@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2013 Bezleputh
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 from woob.capabilities.job import CapJob
 from woob.tools.application.repl import ReplApplication, defaultcount
 from woob.tools.application.formatters.iformatter import IFormatter, PrettyFormatter
@@ -31,7 +27,7 @@ class JobAdvertFormatter(IFormatter):
     MANDATORY_FIELDS = ('id', 'url', 'publication_date', 'title')
 
     def format_obj(self, obj, alias):
-        result = u'%s%s%s\n' % (self.BOLD, obj.title, self.NC)
+        result = '%s%s%s\n' % (self.BOLD, obj.title, self.NC)
         result += 'url: %s\n' % obj.url
         if hasattr(obj, 'publication_date') and obj.publication_date:
             result += 'Publication date : %s\n' % obj.publication_date.strftime('%Y-%m-%d')
@@ -61,7 +57,7 @@ class JobAdvertListFormatter(PrettyFormatter):
         return '%s' % (obj.title)
 
     def get_description(self, obj):
-        result = u''
+        result = ''
         if hasattr(obj, 'publication_date') and obj.publication_date:
             result += '\tPublication date : %s\n' % obj.publication_date.strftime('%Y-%m-%d')
         if hasattr(obj, 'place') and obj.place:
@@ -75,7 +71,7 @@ class JobAdvertListFormatter(PrettyFormatter):
 
 class AppJob(ReplApplication):
     APPNAME = 'job'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2012-YEAR Bezleputh'
     DESCRIPTION = "Console application to search for a job."
     SHORT_DESCRIPTION = "search for a job"
@@ -95,7 +91,7 @@ class AppJob(ReplApplication):
 
         Search for an advert  matching a PATTERN.
         """
-        self.change_path([u'search'])
+        self.change_path(['search'])
         self.start_format(pattern=pattern)
         for job_advert in self.do('search_job', pattern):
             self.cached_format(job_advert)
@@ -107,7 +103,7 @@ class AppJob(ReplApplication):
 
         Search for an advert matching to advanced filters.
         """
-        self.change_path([u'advanced'])
+        self.change_path(['advanced'])
         for job_advert in self.do('advanced_search_job'):
             self.cached_format(job_advert)
 
