@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2013  Romain Bignon
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 from woob.capabilities.base import empty
 from woob.capabilities.parcel import CapParcel, Parcel, ParcelNotFound
 from woob.core import CallErrors
@@ -45,14 +41,14 @@ class HistoryFormatter(IFormatter):
 
     def format_obj(self, obj, alias):
         if isinstance(obj, Parcel):
-            result =  u'Parcel %s (%s)\n' % (self.colored(obj.id, 'red', 'bold'),
+            result =  'Parcel %s (%s)\n' % (self.colored(obj.id, 'red', 'bold'),
                                               self.colored(obj.backend, 'blue', 'bold'))
-            result += u'%sArrival:%s %s\n' % (self.BOLD, self.NC, obj.arrival)
+            result += '%sArrival:%s %s\n' % (self.BOLD, self.NC, obj.arrival)
             status, status_color = STATUS[obj.status]
-            result += u'%sStatus:%s  %s\n' % (self.BOLD, self.NC, self.colored(status, status_color))
-            result += u'%sInfo:%s  %s\n\n' % (self.BOLD, self.NC, obj.info)
-            result += u' Date                  Location          Activity                                          \n'
-            result += u'---------------------+-----------------+---------------------------------------------------'
+            result += '%sStatus:%s  %s\n' % (self.BOLD, self.NC, self.colored(status, status_color))
+            result += '%sInfo:%s  %s\n\n' % (self.BOLD, self.NC, obj.info)
+            result += ' Date                  Location          Activity                                          \n'
+            result += '---------------------+-----------------+---------------------------------------------------'
             return result
 
         return ' %s   %s %s' % (self.colored('%-19s' % obj.date, 'blue'),
@@ -75,7 +71,7 @@ class StatusFormatter(IFormatter):
 
         status, status_color = STATUS[obj.status]
         arrival = obj.arrival.strftime('%Y-%m-%d') if not empty(obj.arrival) else ''
-        result = u'%s %s %s %s  %s' % (id, self.colored(u'—', 'cyan'),
+        result = '%s %s %s %s  %s' % (id, self.colored('—', 'cyan'),
                                        self.colored('%-10s' % status, status_color),
                                        self.colored('%-10s' % arrival, 'blue'),
                                        self.colored('%-20s' % obj.info, 'yellow'))
@@ -86,7 +82,7 @@ class StatusFormatter(IFormatter):
 class AppParcel(ReplApplication):
     APPNAME = 'parcel'
     OLD_APPNAME = 'parceloob'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2013-YEAR Romain Bignon'
     CAPS = CapParcel
     DESCRIPTION = "Console application to track your parcels."
