@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2013 Julien Veyssier
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 import codecs
 
 from woob.capabilities.recipe import CapRecipe
@@ -34,7 +30,7 @@ class RecipeInfoFormatter(IFormatter):
     MANDATORY_FIELDS = ('id', 'title', 'preparation_time', 'ingredients', 'instructions')
 
     def format_obj(self, obj, alias):
-        result = u'%s%s%s\n' % (self.BOLD, obj.title, self.NC)
+        result = '%s%s%s\n' % (self.BOLD, obj.title, self.NC)
         result += 'ID: %s\n' % obj.fullid
         if not empty(obj.author):
             result += 'Author: %s\n' % obj.author
@@ -53,7 +49,7 @@ class RecipeInfoFormatter(IFormatter):
         if not empty(obj.comments):
             result += '\n%sComments%s\n' % (self.BOLD, self.NC)
             for c in obj.comments:
-                result += u'  * %s\n' % c
+                result += '  * %s\n' % c
         return result
 
 
@@ -64,7 +60,7 @@ class RecipeListFormatter(PrettyFormatter):
         return obj.title
 
     def get_description(self, obj):
-        result = u''
+        result = ''
         if not empty(obj.preparation_time):
             result += 'prep time: %smin' % obj.preparation_time
         if not empty(obj.short_description):
@@ -74,7 +70,7 @@ class RecipeListFormatter(PrettyFormatter):
 
 class AppRecipes(ReplApplication):
     APPNAME = 'recipes'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2013-YEAR Julien Veyssier'
     DESCRIPTION = "Console application allowing to search for recipes on various websites."
     SHORT_DESCRIPTION = "search and consult recipes"
@@ -153,7 +149,7 @@ class AppRecipes(ReplApplication):
 
         Search recipes.
         """
-        self.change_path([u'search'])
+        self.change_path(['search'])
         self.start_format(pattern=pattern)
         for recipe in self.do('iter_recipes', pattern=pattern):
             self.cached_format(recipe)
