@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2012  Lucien Loiseau
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 import re
 
 from woob.capabilities.translate import CapTranslate, TranslationFail, LanguageNotSupported
@@ -34,7 +30,7 @@ class TranslationFormatter(IFormatter):
     MANDATORY_FIELDS = ('id', 'text')
 
     def format_obj(self, obj, alias):
-        return u'%s* %s%s\n\t[%s] %s' % (self.BOLD, obj.backend, self.NC, obj.lang_dst, obj.text.replace('\n', '\n\t'))
+        return '%s* %s%s\n\t[%s] %s' % (self.BOLD, obj.backend, self.NC, obj.lang_dst, obj.text.replace('\n', '\n\t'))
 
 
 class XmlTranslationFormatter(IFormatter):
@@ -45,12 +41,12 @@ class XmlTranslationFormatter(IFormatter):
             self.output('<source>\n%s\n</source>' % kwargs['source'])
 
     def format_obj(self, obj, alias):
-        return u'<translation %s>\n%s\n</translation>' % (obj.backend, obj.text)
+        return '<translation %s>\n%s\n</translation>' % (obj.backend, obj.text)
 
 
 class AppTranslate(ReplApplication):
     APPNAME = 'translate'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2012-YEAR Lucien Loiseau'
     DESCRIPTION = "Console application to translate text from one language to another"
     SHORT_DESCRIPTION = "translate text from one language to another"
