@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2013 Romain Bignon, Julien Hébert
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 import datetime
 
 from woob.capabilities.base import Currency, empty
@@ -36,11 +32,11 @@ class DeparturesFormatter(PrettyFormatter):
     def get_title(self, obj):
         s = obj.type
         if hasattr(obj, 'price') and not empty(obj.price):
-            s += u' %s %s' % (self.colored(u'—', 'cyan'), self.colored('%6.2f %s' % (obj.price, Currency.currency2txt(obj.currency)), 'green'))
+            s += ' %s %s' % (self.colored('—', 'cyan'), self.colored('%6.2f %s' % (obj.price, Currency.currency2txt(obj.currency)), 'green'))
         if hasattr(obj, 'late') and not empty(obj.late) and obj.late > datetime.time():
-            s += u' %s %s' % (self.colored(u'—', 'cyan'), self.colored('Late: %s' % obj.late, 'red', 'bold'))
+            s += ' %s %s' % (self.colored('—', 'cyan'), self.colored('Late: %s' % obj.late, 'red', 'bold'))
         if hasattr(obj, 'information') and not empty(obj.information) and obj.information.strip() != '':
-            s += u' %s %s' % (self.colored(u'—', 'cyan'), self.colored(obj.information, 'red'))
+            s += ' %s %s' % (self.colored('—', 'cyan'), self.colored(obj.information, 'red'))
         return s
 
     def get_description(self, obj):
@@ -66,7 +62,7 @@ class StationsFormatter(PrettyFormatter):
 
 class AppTravel(ReplApplication):
     APPNAME = 'travel'
-    VERSION = '3.2'
+    VERSION = '3.5'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Romain Bignon'
     DESCRIPTION = "Console application allowing to search for train stations and get departure times."
     SHORT_DESCRIPTION = "search for train stations and departures"
