@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2014 Romain Bignon
 #
 # This file is part of woob.
@@ -17,11 +15,13 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
+from __future__ import annotations
 
 import datetime
 import re
 import unicodedata
+import pycountry
+from typing import Any
 from collections.abc import Iterator
 from decimal import Decimal, InvalidOperation
 from itertools import islice
@@ -46,7 +46,7 @@ __all__ = [
     'CleanDecimal', 'Slugify', 'Type', 'Field', 'Regexp', 'Map', 'MapIn',
     'DateTime', 'FromTimestamp', 'Date', 'DateGuesser', 'Time', 'Duration',
     'MultiFilter', 'CombineDate', 'Format', 'BrowserURL', 'Join', 'MultiJoin',
-    'Eval', 'QueryValue', 'Coalesce',
+    'Eval', 'QueryValue', 'Coalesce', 'CountryCode',
 ]
 
 
@@ -195,7 +195,7 @@ class RawText(Filter):
     @debug()
     def filter(self, el):
         if isinstance(el, (tuple, list)):
-            return u' '.join([self.filter(e) for e in el])
+            return ' '.join([self.filter(e) for e in el])
 
         if self.children:
             text = el.text_content()
@@ -264,7 +264,7 @@ class CleanText(Filter):
         elif isinstance(txt, int):
             txt = str(txt)
         elif isinstance(txt, (tuple, list)):
-            txt = u' '.join(
+            txt = ' '.join(
                 self.clean(item, newlines=self.newlines, children=self.children)
                 for item in txt
             )
@@ -284,12 +284,12 @@ class CleanText(Filter):
                 txt = list(txt.itertext())
             else:
                 txt = list(txt.xpath('./text()'))
-            txt = u' '.join(txt)  # 'foo   bar '
+            txt = ' '.join(txt)  # 'foo   bar '
         elif not isinstance(txt, str):
-            txt = u' '.join(txt.itertext())
+            txt = ' '.join(txt.itertext())
 
         if newlines:
-            txt = re.compile(r'\s+', flags=re.UNICODE).sub(u' ', txt)  # 'foo bar '
+            txt = re.compile(r'\s+', flags=re.UNICODE).sub(' ', txt)  # 'foo bar '
         else:
             # normalize newlines and clean what is inside
             txt = '\n'.join([cls.clean(l) for l in txt.splitlines()])
@@ -351,6 +351,35 @@ class Currency(CleanText):
         return BaseCurrency.get_currency(txt)
 
 
+class CountryCode(CleanText):
+    """
+    Filter to get the country ISO 3166-1 alpha-2 code from the country name
+    """
+    @debug()
+    def filter(self, txt: str) -> Any:
+        """Get the country code from the name of the country
+
+        :param txt: Country name
+        :type txt: str
+        :raises FormatError: if the Country name is not found
+
+        >>> CountryCode().filter('france')
+        'fr'
+        >>> CountryCode(default= 'll').filter('Greez')
+        'll'
+        """
+        txt = super().filter(txt)
+        if empty(txt):
+            return self.default_or_raise(FormatError("Unable to parse %r" % txt))
+        try:
+            alpha_2_code = pycountry.countries.lookup(txt).alpha_2.lower()
+        except LookupError:
+            # Country not found
+            return self.default_or_raise(FormatError('Country not recognized: %r' % txt))
+
+        return alpha_2_code
+
+
 class NumberFormatError(FormatError, InvalidOperation):
     pass
 
@@ -398,7 +427,7 @@ class CleanDecimal(CleanText):
 
         original_text = text = super(CleanDecimal, self).filter(text)
 
-        text = text.replace(u'\u2212', '-')
+        text = text.replace('\u2212', '-')
 
         if self.legacy:
             if self.replace_dots:
@@ -581,13 +610,7 @@ class Regexp(Filter):
             raise FilterError('Missing pattern parameter')
         self.pattern = pattern
 
-        # 8192 = regex.VERSION0 / 256 = regex.VERSION1
-        if '(?V0)' in pattern or '(?V1)' in pattern or flags & 8192 or flags & 256:
-            import regex
-            self._regex = regex.compile(pattern, flags)
-        else:
-            self._regex = re.compile(pattern, flags)
-        self._regex = self._regex
+        self._regex = re.compile(pattern, flags)
         self.template = template
         self.nth = nth
 
@@ -606,7 +629,7 @@ class Regexp(Filter):
         """
 
         if isinstance(txt, (tuple, list)):
-            txt = u' '.join([t.strip() for t in txt.itertext()])
+            txt = ' '.join([t.strip() for t in txt.itertext()])
 
         m = None
         try:
@@ -804,7 +827,7 @@ class DateGuesser(Filter):
 class Time(Filter):
     """Parse time."""
 
-    klass = datetime.time
+    klass: type = datetime.time
     _regexp = re.compile(r'(?P<hh>\d+)[:h]?(?P<mm>\d+)([:m](?P<ss>\d+))?')
     kwargs = {'hour': 'hh', 'minute': 'mm', 'second': 'ss'}
 
@@ -826,7 +849,7 @@ class Time(Filter):
 class Duration(Time):
     """Parse a duration as timedelta."""
 
-    klass = datetime.timedelta
+    klass: type = datetime.timedelta
     _regexp = re.compile(r'((?P<hh>\d+)[:;])?(?P<mm>\d+)[;:](?P<ss>\d+)')
     kwargs = {'hours': 'hh', 'minutes': 'mm', 'seconds': 'ss'}
 
