@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-
-# Copyright(C) 2010-2013 Romain Bignon
+# Copyright(C) 2010-2023 Romain Bignon
 #
 # This file is part of woob.
 #
@@ -21,25 +19,74 @@ import importlib
 import logging
 import pkgutil
 import sys
+import warnings
+from inspect import getmodule
+from pathlib import Path
 
+import pkg_resources
+
+from packaging.version import Version
+
+from woob import __version__
+from woob.exceptions import ModuleLoadError
 from woob.tools.backend import Module
 from woob.tools.log import getLogger
-from woob.exceptions import ModuleLoadError
+from woob.tools.packaging import parse_requirements
+
 
 __all__ = ['LoadedModule', 'ModulesLoader', 'RepositoryModulesLoader']
 
 
-class LoadedModule(object):
+class LoadedModule:
     def __init__(self, package):
         self.logger = getLogger('woob.backend')
         self.package = package
         self.klass = None
+
+        full_name = package.__name__
         for attrname in dir(self.package):
             attr = getattr(self.package, attrname)
-            if isinstance(attr, type) and issubclass(attr, Module) and attr != Module:
-                self.klass = attr
+
+            # Check that the attribute is indeed a 'Module' subclass.
+            # Note that we check below if it is indeed defined in the
+            # Python module we're importing, so 'Module' itself or
+            # 'Module' subclasses imported from other Python modules
+            # won't be taken into account.
+            try:
+                if not issubclass(attr, Module):
+                    continue
+            except TypeError:
+                # Argument 1 must be a class.
+                continue
+
+            # Check that the attribute is indeed defined in the loaded
+            # Python module specifically.
+            module = getmodule(attr)
+            if module is None:
+                continue
+
+            module_name = module.__name__
+            if (
+                not module_name.startswith(full_name)
+                or module_name[len(full_name):][:1] not in ('', '.')
+            ):
+                continue
+
+            # Check that there is indeed only one Module subclass defined
+            # in the Python module.
+
+            if self.klass is not None:
+                raise ImportError(
+                    f'At least two modules are defined in "{full_name}": '
+                    + f'{attr!r} and {self.klass!r}',
+                )
+
+            self.klass = attr
+
         if not self.klass:
-            raise ImportError('%s is not a backend (no Module class found)' % package)
+            raise ImportError(
+                f'{package} is not a backend (no Module class found)',
+            )
 
     @property
     def name(self):
@@ -47,11 +94,17 @@ class LoadedModule(object):
 
     @property
     def maintainer(self):
-        return u'%s <%s>' % (self.klass.MAINTAINER, self.klass.EMAIL)
+        return f'{self.klass.MAINTAINER} <{self.klass.EMAIL}>'
 
     @property
     def version(self):
-        return self.klass.VERSION
+        warnings.warn(
+            'The LoadedModule.version attribute will be removed.',
+            DeprecationWarning,
+            stacklevel=2
+        )
+
+        return Version(__version__).base_version
 
     @property
     def description(self):
@@ -70,14 +123,23 @@ class LoadedModule(object):
         if self.klass.BROWSER and hasattr(self.klass.BROWSER, 'BASEURL') and self.klass.BROWSER.BASEURL:
             return self.klass.BROWSER.BASEURL
         if self.klass.BROWSER and hasattr(self.klass.BROWSER, 'DOMAIN') and self.klass.BROWSER.DOMAIN:
-            return '%s://%s' % (self.klass.BROWSER.PROTOCOL, self.klass.BROWSER.DOMAIN)
-        else:
-            return None
+            return f'{self.klass.BROWSER.PROTOCOL}://{self.klass.BROWSER.DOMAIN}'
+
+        return None
 
     @property
     def icon(self):
         return self.klass.ICON
 
+    @property
+    def path(self):
+        try:
+            return self.package.__path__[0]
+        except AttributeError:
+            # This might yield 'mymodule/__init__.py' instead of 'mymodule'
+            # like the previous version, so we keep the first version if avail.
+            return getmodule(self.package).__file__
+
     @property
     def dependencies(self):
         return self.klass.DEPENDENCIES
@@ -95,7 +157,7 @@ class LoadedModule(object):
 
     def create_instance(self, woob, backend_name, config, storage, nofail=False, logger=None):
         backend_instance = self.klass(woob, backend_name, config, storage, logger=logger or self.logger, nofail=nofail)
-        self.logger.debug(u'Created backend "%s" for module "%s"' % (backend_name, self.name))
+        self.logger.debug('Created backend "%s" for module "%s"', backend_name, self.name)
         return backend_instance
 
 
@@ -114,7 +176,7 @@ def _add_in_modules_path(path):
             woob_modules.__path__.append(path)
 
 
-class ModulesLoader(object):
+class ModulesLoader:
     """
     Load modules.
     """
@@ -125,7 +187,7 @@ class ModulesLoader(object):
         if self.path:
             _add_in_modules_path(self.path)
         self.loaded = {}
-        self.logger = getLogger("%s.loader" % __name__)
+        self.logger = getLogger(f"{__name__}.loader")
 
     def get_or_load_module(self, module_name):
         """
@@ -142,6 +204,8 @@ class ModulesLoader(object):
             return
 
         for module in pkgutil.iter_modules(woob_modules.__path__):
+            if module.name.startswith('_') or module.name.endswith('_'):
+                continue
             yield module.name
 
     def module_exists(self, name):
@@ -166,24 +230,67 @@ class ModulesLoader(object):
 
         _add_in_modules_path(module_path)
 
+        # Load spec for now to check version without trying to load the module,
+        # as if it depends of an uninstalled dependence or a newest version of
+        # woob, it may crash.
+        module_spec = importlib.util.find_spec(f'woob_modules.{module_name}')
+        if module_spec is None:
+            raise ModuleLoadError(module_name, f'Module {module_name} does not exist')
+        self.check_version(module_name, module_spec)
+
         try:
-            pymodule = importlib.import_module('woob_modules.%s' % module_name)
+            pymodule = importlib.import_module(f'woob_modules.{module_name}')
             module = LoadedModule(pymodule)
         except Exception as e:
             if logging.root.level <= logging.DEBUG:
                 self.logger.exception(e)
-            raise ModuleLoadError(module_name, e)
-
-        if module.version != self.version:
-            raise ModuleLoadError(module_name, "Module requires Woob %s, but you use Woob %s. Hint: use 'woob config update'"
-                                               % (module.version, self.version))
+            raise ModuleLoadError(module_name, e) from e
 
         self.loaded[module_name] = module
-        self.logger.debug('Loaded module "%s" from %s' % (module_name, module.package.__path__[0]))
+        self.logger.debug('Loaded module "%s" from %s' % (
+            module.name,
+            module.path,
+        ))
 
     def get_module_path(self, module_name):
         return self.path
 
+    def check_version(self, module_name, module_spec):
+        woob_version = Version(self.version)
+
+        # For a directory module, module_spec.origin is
+        # 'woob_modules/bnp/__init__.py' so get 'woob_modules/bnp'.
+        # For a single-file module, module_spec.origin is
+        # 'woob_modules/bnp.py' so get 'woob_modules/'.
+        # In that case, that's not a problem, we can assume the parent
+        # requirements.txt file applies on all single-file modules.
+        requirements_path = Path(module_spec.origin).parent / 'requirements.txt'
+
+        for name, spec in parse_requirements(requirements_path).items():
+            if name == 'woob':
+                if woob_version not in spec:
+                    # specific user friendly error message
+                    raise ModuleLoadError(
+                        module_name,
+                        f"Module requires woob {spec}, but you use woob {self.version}'.\n"
+                        "Hint: use 'woob update' or install a newer version of woob"
+                    )
+                continue
+
+            try:
+                pkg = pkg_resources.get_distribution(name)
+            except pkg_resources.DistributionNotFound as exc:
+                raise ModuleLoadError(
+                    module_name,
+                    f'Module requires python package "{name}" but not installed.'
+                ) from exc
+
+            if Version(pkg.version) not in spec:
+                raise ModuleLoadError(
+                    module_name,
+                    f'Modure requires python package "{name}" {spec} but version {pkg.version} is installed'
+                )
+
 
 class RepositoryModulesLoader(ModulesLoader):
     """
@@ -191,7 +298,7 @@ class RepositoryModulesLoader(ModulesLoader):
     """
 
     def __init__(self, repositories):
-        super(RepositoryModulesLoader, self).__init__(repositories.modules_dir, repositories.version)
+        super().__init__(repositories.modules_dir, repositories.version)
         self.repositories = repositories
         # repositories.modules_dir is ...../woob_modules
         # shouldn't be in sys.path, its parent should
@@ -205,8 +312,8 @@ class RepositoryModulesLoader(ModulesLoader):
     def get_module_path(self, module_name):
         minfo = self.repositories.get_module_info(module_name)
         if minfo is None:
-            raise ModuleLoadError(module_name, 'No such module %s' % module_name)
+            raise ModuleLoadError(module_name, f'No such module {module_name}')
         if minfo.path is None:
-            raise ModuleLoadError(module_name, 'Module %s is not installed' % module_name)
+            raise ModuleLoadError(module_name, f'Module {module_name} is not installed')
 
         return minfo.path
