@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2012 Romain Bignon, Christophe Benz
 #
 # This file is part of woob.
@@ -18,8 +16,6 @@
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
 
-from __future__ import print_function
-
 import logging
 import optparse
 from optparse import OptionGroup, OptionParser
@@ -45,7 +41,7 @@ class MoreResultsAvailable(Exception):
     pass
 
 
-class ApplicationStorage(object):
+class ApplicationStorage:
     def __init__(self, name, storage):
         self.name = name
         self.storage = storage
@@ -73,7 +69,7 @@ class ApplicationStorage(object):
             return self.storage.save('applications', self.name)
 
 
-class Application(object):
+class Application:
     """
     Base application.
 
@@ -300,7 +296,7 @@ class Application(object):
             exclude = self.options.exclude_backends.split(',')
         loaded = self.woob.load_backends(caps, names, exclude=exclude, *args, **kwargs)
         if not loaded:
-            logging.info(u'No backend loaded')
+            logging.info('No backend loaded')
         return loaded
 
     def _get_optparse_version(self):
@@ -366,7 +362,7 @@ class Application(object):
         if isinstance(error, MoreResultsAvailable):
             return False
 
-        print(u'Error(%s): %s' % (backend.name, error), file=self.stderr)
+        print('Error(%s): %s' % (backend.name, error), file=self.stderr)
         if logging.root.level <= logging.DEBUG:
             print(backtrace, file=self.stderr)
         else:
@@ -440,6 +436,8 @@ class Application(object):
         if not self.options.debug and not self.options.save_responses:
             warnings.simplefilter('ignore', category=ConversionWarning)
             warnings.simplefilter('ignore', category=FormFieldConversionWarning)
+        else:
+            warnings.simplefilter('default')
 
         handlers = []
 
