@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2012  Christophe Benz, Romain Bignon
 #
 # This file is part of woob.
@@ -17,8 +15,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-
-from __future__ import print_function
+from __future__ import annotations
 
 from collections import OrderedDict
 from copy import copy
@@ -29,15 +26,18 @@ import subprocess
 from subprocess import check_output
 import sys
 import os
+from tempfile import NamedTemporaryFile
 
 from woob.capabilities import UserError
 from woob.capabilities.account import CapAccount, Account, AccountRegisterError
 from woob.core.backendscfg import BackendAlreadyExists
 from woob.core.repositories import IProgress
-from woob.exceptions import BrowserUnavailable, BrowserIncorrectPassword, BrowserForbidden, \
-                              BrowserSSLError, BrowserQuestion, BrowserHTTPSDowngrade, \
-                              ModuleInstallError, ModuleLoadError, NoAccountsException, \
-                              ActionNeeded, CaptchaQuestion, NeedInteractiveFor2FA
+from woob.exceptions import (
+    BrowserUnavailable, BrowserIncorrectPassword, BrowserForbidden,
+    BrowserSSLError, BrowserQuestion, BrowserHTTPSDowngrade,
+    ModuleInstallError, ModuleLoadError, ActionNeeded, CaptchaQuestion,
+    NeedInteractiveFor2FA,
+)
 from woob.tools.value import Value, ValueBool, ValueFloat, ValueInt, ValueBackendPassword
 from woob.tools.misc import to_unicode
 
@@ -51,7 +51,7 @@ class BackendNotGiven(Exception):
     def __init__(self, id, backends):
         self.id = id
         self.backends = sorted(backends)
-        super(BackendNotGiven, self).__init__('Please specify a backend to use for this argument (%s@backend_name). '
+        super().__init__('Please specify a backend to use for this argument (%s@backend_name). '
                 'Availables: %s.' % (id, ', '.join(name for name, backend in backends)))
 
 
@@ -98,7 +98,7 @@ class ConsoleApplication(Application):
         NC     = '[0m'    # no color
 
     def __init__(self, option_parser=None):
-        super(ConsoleApplication, self).__init__(option_parser)
+        super().__init__(option_parser)
         self.woob.requests.register('login', self.login_cb)
         self.enabled_backends = set()
         self._parser.add_option('--auto-update', action='store_true',
@@ -128,10 +128,10 @@ class ConsoleApplication(Application):
             errors = kwargs['errors']
         else:
             kwargs['errors'] = errors = []
-        ret = super(ConsoleApplication, self).load_backends(*args, **kwargs)
+        ret = super().load_backends(*args, **kwargs)
 
         for err in errors:
-            print(u'Error(%s): %s' % (err.backend_name, err), file=self.stderr)
+            print('Error(%s): %s' % (err.backend_name, err), file=self.stderr)
             if self.ask('Do you want to reconfigure this backend?', default=True):
                 self.edit_backend(err.backend_name)
                 self.load_backends(names=[err.backend_name])
@@ -222,7 +222,7 @@ class ConsoleApplication(Application):
     @classmethod
     def run(klass, args=None):
         try:
-            super(ConsoleApplication, klass).run(args)
+            super().run(args)
         except BackendNotFound as e:
             print('Error: Backend "%s" not found.' % e)
             sys.exit(1)
@@ -296,7 +296,7 @@ class ConsoleApplication(Application):
             try:
                 backend.klass.register_account(account)
             except AccountRegisterError as e:
-                print(u'%s' % e)
+                print('%s' % e)
                 if self.ask('Do you want to try again?', default=True):
                     continue
                 else:
@@ -313,11 +313,11 @@ class ConsoleApplication(Application):
 
         return backend_config
 
-    def install_module(self, name):
+    def install_module(self, minfo):
         try:
-            self.woob.repositories.install(name, ConsoleProgress(self))
+            self.woob.repositories.install(minfo, ConsoleProgress(self))
         except ModuleInstallError as e:
-            print('Unable to install module "%s": %s' % (name, e), file=self.stderr)
+            print('Unable to install module "%s": %s' % (minfo.name, e), file=self.stderr)
             return False
 
         print('')
@@ -337,9 +337,10 @@ class ConsoleApplication(Application):
                 minfo = self.woob.repositories.get_module_info(module_name)
                 if minfo is None:
                     raise ModuleLoadError(module_name, 'Module does not exist')
-                if not minfo.is_installed():
-                    print('Module "%s" is available but not installed.' % minfo.name)
-                    self.install_module(minfo)
+
+                if not minfo.is_installed() and not self.install_module(minfo):
+                    return
+
                 module = self.woob.modules_loader.get_or_load_module(module_name)
                 config = module.config
             else:
@@ -350,7 +351,7 @@ class ConsoleApplication(Application):
                 config = module.config.load(self.woob, module_name, backend_name, params, nofail=True)
         except ModuleLoadError as e:
             print('Unable to load module "%s": %s' % (module_name, e), file=self.stderr)
-            return 1
+            return
 
         # ask for params non-specified on command-line arguments
         asked_config = False
@@ -366,7 +367,7 @@ class ConsoleApplication(Application):
             if key not in params or edit:
                 params[key] = self.ask(value, default=params[key] if (key in params) else value.default)
             else:
-                print(u'[%s] %s: %s' % (key, value.description, '(masked)' if value.masked else to_unicode(params[key])))
+                print('[%s] %s: %s' % (key, value.description, '(masked)' if value.masked else to_unicode(params[key])))
         if asked_config:
             print('-------------------------%s' % ('-' * len(module.name)))
 
@@ -378,33 +379,38 @@ class ConsoleApplication(Application):
             backend_name = backend_name.rstrip('0123456789')
             while self.woob.backends_config.backend_exists('%s%s' % (backend_name, i)):
                 i += 1
-            backend_name = self.ask('Please give new instance name', default='%s%s' % (backend_name, i), regexp=r'^[\w\-_]+$')
+            backend_name = self.ask('Please give new backend name', default='%s%s' % (backend_name, i), regexp=r'^[\w\-_]+$')
 
-        try:
-            config = config.load(self.woob, module.name, backend_name, params, nofail=True)
-            for key, value in params.items():
-                if key not in config:
-                    continue
-                config[key].set(value)
+        if edit:
+            self.woob.backends_config.edit_backend(backend_name, params)
+        else:
+            try:
+                self.woob.backends_config.add_backend(backend_name, module.name, params)
+            except BackendAlreadyExists:
+                print('Backend "%s" already exists.' % backend_name, file=self.stderr)
+                return None
 
-            config.save(edit=edit)
-            print('Backend "%s" successfully %s.' % (backend_name, 'edited' if edit else 'added'))
-            return backend_name
-        except BackendAlreadyExists:
-            print('Backend "%s" already exists.' % backend_name, file=self.stderr)
-            return 1
+        print('Backend "%s" successfully %s.' % (backend_name, 'edited' if edit else 'added'))
+        return backend_name
 
     def ask(self, question, default=None, masked=None, regexp=None, choices=None, tiny=None):
         """
         Ask a question to user.
 
-        @param question  text displayed (str)
-        @param default  optional default value (str)
-        @param masked  if True, do not show typed text (bool)
-        @param regexp  text must match this regexp (str)
-        @param choices  choices to do (list)
-        @param tiny  ask for the (small) value of the choice (bool)
-        @return  entered text by user (str)
+        :param question: text displayed
+        :type question: str
+        :param default: optional default value
+        :type default: str
+        :param masked: if True, do not show typed text
+        :type masked: bool
+        :param regexp: text must match this regexp
+        :type regexp: str
+        :param choices: choices to do
+        :type choices: list
+        :param tiny: ask for the (small) value of the choice
+        :type tiny: bool
+        :returns: text by user
+        :rtype: str
         """
 
         if isinstance(question, Value):
@@ -433,9 +439,9 @@ class ConsoleApplication(Application):
 
         question = v.label
         if v.description and v.description != v.label:
-            question = u'%s: %s' % (question, v.description)
+            question = '%s: %s' % (question, v.description)
         if v.id:
-            question = u'[%s] %s' % (v.id, question)
+            question = '[%s] %s' % (v.id, question)
 
         if isinstance(v, ValueBackendPassword):
             print(question + ':')
@@ -467,7 +473,7 @@ class ConsoleApplication(Application):
 
         aliases = {}
         if isinstance(v, ValueBool):
-            question = u'%s (%s/%s)' % (question, 'Y' if v.default else 'y', 'n' if v.default else 'N')
+            question = '%s (%s/%s)' % (question, 'Y' if v.default else 'y', 'n' if v.default else 'N')
         elif v.choices:
             if v.tiny is None:
                 v.tiny = True
@@ -477,7 +483,7 @@ class ConsoleApplication(Application):
                         break
 
             if v.tiny:
-                question = u'%s (%s)' % (question, '/'.join((s.upper() if s == v.default else s)
+                question = '%s (%s)' % (question, '/'.join((s.upper() if s == v.default else s)
                                                             for s in v.choices))
                 for s in v.choices:
                     if s == v.default:
@@ -488,12 +494,12 @@ class ConsoleApplication(Application):
                 for n, (key, value) in enumerate(v.choices.items()):
                     print('     %s%2d)%s %s' % (self.BOLD, n + 1, self.NC, value))
                     aliases[str(n + 1)] = key
-                question = u'%s (choose in list)' % question
+                question = '%s (choose in list)' % question
         if v.masked:
-            question = u'%s (hidden input)' % question
+            question = '%s (hidden input)' % question
 
         if not isinstance(v, ValueBool) and not v.tiny and v.default not in (None, ''):
-            question = u'%s [%s]' % (question, '*******' if v.masked else v.default)
+            question = '%s [%s]' % (question, '*******' if v.masked else v.default)
 
         question += ': '
 
@@ -521,7 +527,7 @@ class ConsoleApplication(Application):
             try:
                 v.set(line)
             except ValueError as e:
-                print(u'Error: %s' % e, file=self.stderr)
+                print('Error: %s' % e, file=self.stderr)
             else:
                 break
 
@@ -531,15 +537,40 @@ class ConsoleApplication(Application):
     def print(self, txt):
         print(txt)
 
-    def acquire_input(self, content=None, editor_params=None):
+    def acquire_input(
+        self,
+        content: str | bytes | None = None,
+        editor_params: dict[str, str] | None = None,
+        suffix: str | None = None
+    ) -> str:
+        """
+        Get an input from a text editor.
+
+        If the EDITOR environment variable is empty, acquire from stdin.
+
+        You can provide ``editor_params`` to supply parameters to editor.
+        For example::
+
+            {'vim': "-c 'set ft=mail'"}
+
+        The ``suffix`` argument is for the temporary filename, that's useful to
+        highlight content.
+
+        :param content: default content to write in the file to edit
+        :type content: str
+        :param editor_params: parameters to supply to editor
+        :type editor_params: dict
+        :param suffix: file suffix
+        :type suffix: str
+        :rtype: str
+        """
         editor = os.getenv('EDITOR', 'vi')
         if self.stdin.isatty() and editor:
-            from tempfile import NamedTemporaryFile
-            with NamedTemporaryFile() as f:
+            with NamedTemporaryFile(suffix=suffix) as f:
                 filename = f.name
                 if content is not None:
                     if isinstance(content, str):
-                        content = content
+                        content = content.encode('utf-8')
                     f.write(content)
                     f.flush()
                 try:
@@ -569,7 +600,7 @@ class ConsoleApplication(Application):
                 if v:
                     backend.config[field.id].set(v)
         elif isinstance(error, CaptchaQuestion):
-            print(u'Warning(%s): Captcha has been found on login page' % backend.name, file=self.stderr)
+            print('Warning(%s): Captcha has been found on login page' % backend.name, file=self.stderr)
         elif isinstance(error, BrowserIncorrectPassword):
             msg = str(error)
             if not msg:
@@ -580,32 +611,30 @@ class ConsoleApplication(Application):
                 self.edit_backend(backend.name)
                 self.load_backends(names=[backend.name])
         elif isinstance(error, BrowserSSLError):
-            print(u'FATAL(%s): ' % backend.name + self.BOLD + r'/!\ SERVER CERTIFICATE IS INVALID /!\\' + self.NC, file=self.stderr)
+            print('FATAL(%s): ' % backend.name + self.BOLD + r'/!\ SERVER CERTIFICATE IS INVALID /!\\' + self.NC, file=self.stderr)
         elif isinstance(error, BrowserHTTPSDowngrade):
-            print(u'FATAL(%s): ' % backend.name + 'Downgrade from HTTPS to HTTP')
+            print('FATAL(%s): ' % backend.name + 'Downgrade from HTTPS to HTTP')
         elif isinstance(error, BrowserForbidden):
             msg = str(error)
-            print(u'Error(%s): %s' % (backend.name, msg or 'Forbidden'), file=self.stderr)
+            print('Error(%s): %s' % (backend.name, msg or 'Forbidden'), file=self.stderr)
         elif isinstance(error, BrowserUnavailable):
             msg = str(error)
-            print(u'Error(%s): %s' % (backend.name, msg or 'Website is unavailable.'), file=self.stderr)
+            print('Error(%s): %s' % (backend.name, msg or 'Website is unavailable.'), file=self.stderr)
         elif isinstance(error, ActionNeeded):
             msg = str(error)
-            print(u'Error(%s): Action needed on website: %s' % (backend.name, msg), file=self.stderr)
+            print('Error(%s): Action needed on website: %s' % (backend.name, msg), file=self.stderr)
         elif isinstance(error, NotImplementedError):
-            print(u'Error(%s): this feature is not supported yet by this backend.' % backend.name, file=self.stderr)
-            print(u'      %s   To help the maintainer of this backend implement this feature,' % (' ' * len(backend.name)), file=self.stderr)
-            print(u'      %s   please contact us on the project mailing list' % (' ' * len(backend.name)), file=self.stderr)
+            print('Error(%s): this feature is not supported yet by this backend.' % backend.name, file=self.stderr)
+            print('      %s   To help the maintainer of this backend implement this feature,' % (' ' * len(backend.name)), file=self.stderr)
+            print('      %s   please contact us on the project mailing list' % (' ' * len(backend.name)), file=self.stderr)
         elif isinstance(error, NeedInteractiveFor2FA):
-            print(u'Error(%s): You have to run %s in interactive mode to perform a two-factor authentication' % (backend.name, self.APPNAME), file=self.stderr)
+            print('Error(%s): You have to run %s in interactive mode to perform a two-factor authentication' % (backend.name, self.APPNAME), file=self.stderr)
         elif isinstance(error, UserError):
-            print(u'Error(%s): %s' % (backend.name, error), file=self.stderr)
+            print('Error(%s): %s' % (backend.name, error), file=self.stderr)
         elif isinstance(error, MoreResultsAvailable):
-            print(u'Hint: There are more results for backend %s' % (backend.name), file=self.stderr)
-        elif isinstance(error, NoAccountsException):
-            print(u'Error(%s): %s' % (backend.name, str(error) or 'No account on this backend'), file=self.stderr)
+            print('Hint: There are more results for backend %s' % (backend.name), file=self.stderr)
         else:
-            print(u'Bug(%s): %s' % (backend.name, error), file=self.stderr)
+            print('Bug(%s): %s' % (backend.name, error), file=self.stderr)
 
             minfo = self.woob.repositories.get_module_info(backend.NAME)
             if minfo and not minfo.is_local():
@@ -614,10 +643,13 @@ class ConsoleApplication(Application):
 
                     # minfo of the new available module
                     minfo = self.woob.repositories.get_module_info(backend.NAME)
-                    if minfo and minfo.version > self.woob.repositories.versions.get(minfo.name) and \
-                       self.ask('A new version of %s is available. Do you want to install it?' % minfo.name, default=True) and \
-                       self.install_module(minfo):
-                        print('New version of module %s has been installed. Retry to call the command.' % minfo.name)
+                    if (
+                        minfo and
+                        minfo.version > self.woob.repositories.versions.get(minfo.name) and
+                        self.ask(f'A new version of {minfo.name} is available. Do you want to install it?', default=True) and
+                        self.install_module(minfo)
+                    ):
+                        print(f'New version of module {minfo.name} has been installed. Retry to call the command.')
                         return
                 else:
                     print('(If --auto-update is passed on the command-line, new versions of the module will be checked automatically)')
