@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2010-2021  Christophe Benz, Romain Bignon
 #
 # This file is part of woob.
@@ -17,8 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import print_function
-
 import atexit
 import logging
 import os
@@ -30,6 +26,8 @@ from collections import OrderedDict, deque
 from datetime import datetime
 from optparse import IndentedHelpFormatter, OptionGroup, OptionParser
 
+import yaml
+
 from woob.capabilities.base import BaseObject, FieldNotFound, UserError, empty
 from woob.capabilities.collection import BaseCollection, CapCollection, Collection, CollectionNotFound
 from woob.core import CallErrors
@@ -41,8 +39,10 @@ from .console import BackendNotGiven, ConsoleApplication
 from .formatters.load import FormatterLoadError, FormattersLoader
 from .results import ResultsCondition, ResultsConditionError
 
-__all__ = ['NotEnoughArguments', 'TooManyArguments', 'ArgSyntaxError',
-           'ReplApplication']
+__all__ = [
+    'NotEnoughArguments', 'TooManyArguments', 'ArgSyntaxError',
+    'ReplApplication'
+]
 
 
 class NotEnoughArguments(Exception):
@@ -68,7 +68,7 @@ class ReplOptionParser(OptionParser):
 
 class ReplOptionFormatter(IndentedHelpFormatter):
     def format_commands(self, commands):
-        s = u''
+        s = ''
         for section, cmds in commands.items():
             if len(cmds) == 0:
                 continue
@@ -117,11 +117,11 @@ class ReplApplication(ConsoleApplication, Cmd):
     COLLECTION_OBJECTS = tuple()
     """Objects to allow in do_ls / do_cd"""
 
-    woob_commands = set(['backends', 'condition', 'count', 'formatter', 'logging', 'select', 'quit', 'ls', 'cd'])
-    hidden_commands = set(['EOF'])
+    woob_commands = {'backends', 'condition', 'count', 'formatter', 'logging', 'select', 'quit', 'ls', 'cd', 'storage'}
+    hidden_commands = {'EOF'}
 
     def __init__(self):
-        super(ReplApplication, self).__init__(ReplOptionParser(self.SYNOPSIS, version=self._get_optparse_version()))
+        super().__init__(ReplOptionParser(self.SYNOPSIS, version=self._get_optparse_version()))
 
         copyright = self.COPYRIGHT.replace('YEAR', '%d' % datetime.today().year)
         self.intro = '\n'.join(('Welcome to %s%s%s v%s' % (self.BOLD, self.APPNAME, self.NC, self.VERSION),
@@ -155,7 +155,7 @@ class ReplApplication(ConsoleApplication, Cmd):
         formatting_options = OptionGroup(self._parser, 'Formatting Options')
         available_formatters = self.formatters_loader.get_available_formatters()
         formatting_options.add_option('-f', '--formatter', choices=available_formatters,
-                                      help='select output formatter (%s)' % u', '.join(available_formatters))
+                                      help='select output formatter (%s)' % ', '.join(available_formatters))
         formatting_options.add_option('--no-header', dest='no_header', action='store_true', help='do not display header')
         formatting_options.add_option('--no-keys', dest='no_keys', action='store_true', help='do not display item keys')
         formatting_options.add_option('-O', '--outfile', dest='outfile', help='file to export result')
@@ -306,12 +306,12 @@ class ReplApplication(ConsoleApplication, Cmd):
     def load_backends(self, *args, **kwargs):
         self.objects = []
         self.collections = []
-        return super(ReplApplication, self).load_backends(*args, **kwargs)
+        return super().load_backends(*args, **kwargs)
 
     def main(self, argv):
         cmd_args = argv[1:]
         if cmd_args:
-            cmd_line = u' '.join(cmd_args)
+            cmd_line = ' '.join(cmd_args)
             cmds = cmd_line.split(';')
             for cmd in cmds:
                 ret = self.onecmd(cmd)
@@ -432,7 +432,7 @@ class ReplApplication(ConsoleApplication, Cmd):
                         v = self.ask(field)
                         backend.config[field.id].set(v)
                 elif isinstance(error, BrowserRedirect):
-                    print(u'Open this URL in a browser:')
+                    print('Open this URL in a browser:')
                     print(error.url)
                     print()
                     value = self.ask('Please enter the final URL')
@@ -526,7 +526,7 @@ class ReplApplication(ConsoleApplication, Cmd):
 
         try:
             try:
-                return super(ReplApplication, self).onecmd(line)
+                return super().onecmd(line)
             except CallErrors as e:
                 return self.bcall_errors_handler(e)
             except BackendNotGiven as e:
@@ -568,7 +568,7 @@ class ReplApplication(ConsoleApplication, Cmd):
         return [name for name in super().completenames(text, *ignored) if name not in self.hidden_commands]
 
     def _shell_completion_items(self):
-        items = super(ReplApplication, self)._shell_completion_items()
+        items = super()._shell_completion_items()
         items.update(
             set(self.completenames('')) -
             set(('debug', 'condition', 'count', 'formatter', 'logging', 'select', 'quit')))
@@ -596,7 +596,7 @@ class ReplApplication(ConsoleApplication, Cmd):
           * display only proposals for words which match the
             text already written by user.
         """
-        super(ReplApplication, self).complete(text, state)
+        super().complete(text, state)
 
         # When state = 0, Cmd.complete() set the 'completion_matches' attribute by
         # calling the completion function. Then, for other states, it only tries to
@@ -621,13 +621,13 @@ class ReplApplication(ConsoleApplication, Cmd):
 
         This method can be overridden to support more exceptions types.
         """
-        return super(ReplApplication, self).bcall_error_handler(backend, error, backtrace)
+        return super().bcall_error_handler(backend, error, backtrace)
 
     def bcall_errors_handler(self, errors, ignore=()):
         if self.interactive:
-            return super(ReplApplication, self).bcall_errors_handler(errors, 'Use "logging debug" option to print backtraces.', ignore)
+            return super().bcall_errors_handler(errors, 'Use "logging debug" option to print backtraces.', ignore)
         else:
-            return super(ReplApplication, self).bcall_errors_handler(errors, ignore=ignore)
+            return super().bcall_errors_handler(errors, ignore=ignore)
 
     # -- options related methods -------------
     def _handle_options(self):
@@ -653,7 +653,7 @@ class ReplApplication(ConsoleApplication, Cmd):
         else:
             self.condition = None
 
-        return super(ReplApplication, self)._handle_options()
+        return super()._handle_options()
 
     def get_command_help(self, command, short=False):
         try:
@@ -716,7 +716,7 @@ class ReplApplication(ConsoleApplication, Cmd):
             if arg in cmd_names:
                 command_help = self.get_command_help(arg)
                 if command_help is None:
-                    logging.warning(u'Command "%s" is undocumented' % arg)
+                    logging.warning('Command "%s" is undocumented' % arg)
                 else:
                     lines = command_help.split('\n')
                     lines[0] = '%s%s%s' % (self.BOLD, lines[0], self.NC)
@@ -755,6 +755,55 @@ class ReplApplication(ConsoleApplication, Cmd):
 
         return choices
 
+    def do_storage(self, line: str) -> int:
+        """
+        storage [ACTION] [BACKEND_NAME]
+
+        Manipulation of a backend storage.
+
+            * cat           display content of the storage
+            * edit          edit the storage
+            * flush         flush storage
+        """
+        args = line.split()
+        if len(args) != 2:
+            self.do_help('storage')
+            return 1
+
+        try:
+            backend = self.woob.get_backend(args[1])
+        except KeyError:
+            print('No such backend: {args[1]}', file=self.stderr)
+            return 1
+
+        if args[0] == 'cat':
+            storage = backend.storage.get()
+            print(yaml.dump(storage), end='')
+
+            return 0
+
+        if args[0] == 'edit':
+            storage = backend.storage.get()
+            output = self.acquire_input(yaml.dump(storage), suffix='.yml')
+
+            storage = yaml.safe_load(output)
+
+            backend.storage.set(storage)
+            backend.storage.save()
+
+            print(f'Storage for backend {backend.name} has been saved.')
+            return 0
+
+        if args[0] == 'flush':
+            backend.storage.set({})
+            backend.storage.save()
+
+            print(f'Storage for backend {backend.name} has been flushed.')
+            return 0
+
+        print(f'Action not found: {args[0]}', file=self.stderr)
+        return 1
+
     def do_backends(self, line):
         """
         backends [ACTION] [BACKEND_NAME]...
@@ -1186,7 +1235,7 @@ class ReplApplication(ConsoleApplication, Cmd):
                 if len(collections) == 1:
                     self.working_path.split_path = collections[0].split_path
             else:
-                print(u"Path: %s not found" % self.working_path, file=self.stderr)
+                print("Path: %s not found" % self.working_path, file=self.stderr)
                 self.working_path.restore()
                 return 1
 
