@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright(C) 2010-2011 Romain Bignon
+# Copyright(C) 2010-2023 Romain Bignon
 #
 # This file is part of woob.
 #
@@ -16,23 +15,36 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
+import logging
 import importlib
 import os
 from copy import copy
 from threading import RLock
-
+import warnings
 from urllib.request import getproxies
+from typing import List, Any, Dict, Tuple, Iterator, Type, ClassVar, TYPE_CHECKING
 
+from packaging.version import Version
+
+from woob import __version__
 from woob.capabilities.base import BaseObject, Capability, FieldNotFound, NotAvailable, NotLoaded
-from woob.tools.log import getLogger
 from woob.tools.json import json
+from woob.tools.log import getLogger
 from woob.tools.misc import iter_fields
+from woob.tools.storage import IStorage
 from woob.tools.value import ValuesDict
 
+if TYPE_CHECKING:
+    from woob.core import WoobBase
+    from woob.browser import Browser
+
+
 __all__ = ['BackendStorage', 'BackendConfig', 'Module']
 
 
-class BackendStorage(object):
+class BackendStorage:
     """
     This is an abstract layer to store data in storages (:mod:`woob.tools.storage`)
     easily.
@@ -41,11 +53,12 @@ class BackendStorage(object):
     :attr:`Module.storage` attribute.
 
     :param name: name of backend
+    :type name: str
     :param storage: storage object
     :type storage: :class:`woob.tools.storage.IStorage`
     """
 
-    def __init__(self, name, storage):
+    def __init__(self, name: str, storage: IStorage | None):
         self.name = name
         self.storage = storage
 
@@ -63,7 +76,7 @@ class BackendStorage(object):
         :param args: the path where to store value
         """
         if self.storage:
-            return self.storage.set('backends', self.name, *args)
+            self.storage.set('backends', self.name, *args)
 
     def delete(self, *args):
         """
@@ -72,9 +85,9 @@ class BackendStorage(object):
         :param args: path to delete.
         """
         if self.storage:
-            return self.storage.delete('backends', self.name, *args)
+            self.storage.delete('backends', self.name, *args)
 
-    def get(self, *args, **kwargs):
+    def get(self, *args, **kwargs) -> Any:
         """
         Get a value or a dict of values in storage.
 
@@ -94,10 +107,10 @@ class BackendStorage(object):
         """
         if self.storage:
             return self.storage.get('backends', self.name, *args, **kwargs)
-        else:
-            return kwargs.get('default', None)
 
-    def load(self, default):
+        return kwargs.get('default', None)
+
+    def load(self, default: Dict):
         """
         Load storage.
 
@@ -108,14 +121,14 @@ class BackendStorage(object):
         :type default: :class:`dict`
         """
         if self.storage:
-            return self.storage.load('backends', self.name, default)
+            self.storage.load('backends', self.name, default)
 
     def save(self):
         """
         Save storage.
         """
         if self.storage:
-            return self.storage.save('backends', self.name)
+            self.storage.save('backends', self.name)
 
 
 class BackendConfig(ValuesDict):
@@ -128,16 +141,23 @@ class BackendConfig(ValuesDict):
     Then, using the :func:`load` method will load configuration from file and
     create a copy of the :class:`BackendConfig` object with the loaded values.
     """
-    modname = None
-    instname = None
-    woob = None
+    modname: str
+    instname: str
+    woob: WoobBase
 
-    def load(self, woob, modname, instname, config, nofail=False):
+    def load(
+        self,
+        woob: WoobBase,
+        modname: str,
+        instname: str,
+        config: Dict,
+        nofail: bool = False
+    ) -> BackendConfig:
         """
         Load configuration from dict to create an instance.
 
         :param woob: woob object
-        :type woob: :class:`woob.core.woob.Woob`
+        :type woob: :class:`woob.core.woob.WoobBase`
         :param modname: name of the module
         :type modname: :class:`str`
         :param instname: name of this backend
@@ -158,8 +178,7 @@ class BackendConfig(ValuesDict):
             if value is None:
                 if not nofail and field.required:
                     raise Module.ConfigError(
-                        'Backend(%s): Configuration error: Missing parameter "%s" (%s)'
-                        % (cfg.instname, name, field.description),
+                        f'Backend({cfg.instname}): Configuration error: Missing parameter {name} ({field.description})',
                        bad_fields=[name]
                     )
                 value = field.default
@@ -170,14 +189,14 @@ class BackendConfig(ValuesDict):
             except ValueError as v:
                 if not nofail:
                     raise Module.ConfigError(
-                        'Backend(%s): Configuration error for field "%s": %s' % (cfg.instname, name, v),
+                        f'Backend({cfg.instname}): Configuration error for field "{name}": {v}',
                         bad_fields=[name]
                     )
 
             cfg[name] = field
         return cfg
 
-    def dump(self):
+    def dump(self) -> dict:
         """
         Dump config in a dictionary.
 
@@ -189,13 +208,13 @@ class BackendConfig(ValuesDict):
                 settings[name] = value.dump()
         return settings
 
-    def save(self, edit=True, params=None):
+    def save(self, edit: bool = True, params: Dict | None = None):
         """
         Save backend config.
 
         :param edit: if true, it changes config of an existing backend
         :type edit: :class:`bool`
-        :param params: if specified, params to merge with the ones of the current object
+        :param params: if supplied, params to merge with the ones of the current object
         :type params: :class:`dict`
         """
         assert self.modname is not None
@@ -212,7 +231,7 @@ class BackendConfig(ValuesDict):
             self.woob.backends_config.add_backend(self.instname, self.modname, dump)
 
 
-class Module(object):
+class Module:
     """
     Base class for modules.
 
@@ -222,51 +241,49 @@ class Module(object):
     :type woob: :class:`woob.core.woob.Woob`
     :param name: name of backend
     :type name: :class:`str`
-    :param config: configuration of backend
+    :param config: configuration of backend (optional)
     :type config: :class:`dict`
-    :param storage: storage object
+    :param storage: storage object (optional)
     :type storage: :class:`woob.tools.storage.IStorage`
-    :param logger: logger
+    :param logger: parent logger (optional)
     :type logger: :class:`logging.Logger`
     """
-    # Module name.
-    NAME = None
+
+    NAME: ClassVar[str]
     """Name of the maintainer of this module."""
 
-    MAINTAINER = u'<unspecified>'
+    MAINTAINER: ClassVar[str] = '<unspecified>'
+    """Name of the maintainer."""
 
-    EMAIL = '<unspecified>'
+    EMAIL: ClassVar[str] = '<unspecified>'
     """Email address of the maintainer."""
 
-    VERSION = '<unspecified>'
-    """Version of module (for information only)."""
-
-    DESCRIPTION = '<unspecified>'
+    DESCRIPTION: ClassVar[str] = '<unspecified>'
     """Description"""
 
-    # License of this module.
-    LICENSE = '<unspecified>'
+    LICENSE: ClassVar[str] = '<unspecified>'
+    """License of the module"""
 
-    CONFIG = BackendConfig()
+    CONFIG: ClassVar[BackendConfig] = BackendConfig()
     """Configuration required for backends.
 
-    Values must be woob.tools.value.Value objects.
+    Values must be :class:`woob.tools.value.Value` objects.
     """
 
-    STORAGE = {}
+    STORAGE: ClassVar[Dict] = {}
     """Storage"""
 
-    BROWSER = None
+    BROWSER: Browser | None = None
     """Browser class"""
 
-    ICON = None
+    ICON: ClassVar[str | None] = None
     """URL to an optional icon.
 
     If you want to create your own icon, create a 'favicon.png' icon in
     the module's directory, and keep the ICON value to None.
     """
 
-    OBJECTS = {}
+    OBJECTS: ClassVar[Dict] = {}
     """Supported objects to fill
 
     The key is the class and the value the method to call to fill
@@ -275,7 +292,7 @@ class Module(object):
     NOT yet filled.
     """
 
-    DEPENDENCIES = ()
+    DEPENDENCIES: ClassVar[Tuple[str]] = ()
     """Tuple of module names on which this module depends."""
 
     class ConfigError(Exception):
@@ -291,7 +308,7 @@ class Module(object):
             :param bad_fields: names of the config fields which are incorrect
             """
 
-            super(Module.ConfigError, self).__init__(message)
+            super().__init__(message)
             self.bad_fields = bad_fields or ()
 
     def __enter__(self):
@@ -301,7 +318,7 @@ class Module(object):
         self.lock.release()
 
     def __repr__(self):
-        return "<Backend %r>" % self.name
+        return f"<Backend {self.name}>"
 
     def __new__(cls, *args, **kwargs):
         """ Accept any arguments, necessary for AbstractModule __new__ override.
@@ -313,7 +330,36 @@ class Module(object):
         """
         return object.__new__(cls)
 
-    def __init__(self, woob, name, config=None, storage=None, logger=None, nofail=False):
+    @property
+    def VERSION(self):
+        warnings.warn(
+            'Attribute Module.VERSION will be removed in woob 4, do not use it.',
+            DeprecationWarning,
+            stacklevel=3
+        )
+        return Version(__version__).base_version
+
+    def __init__(
+        self,
+        woob: WoobBase,
+        name: str,
+        config: Dict | None = None,
+        storage: IStorage | None = None,
+        logger: logging.Logger | None = None,
+        nofail: bool = False
+    ):
+        if (
+            hasattr(self.__class__, 'VERSION') and
+            not isinstance(self.__class__.VERSION, property)
+        ):
+            warnings.warn(
+                f'Class attribute {self.__class__.__name__}.VERSION is now '
+                'unused and deprecated, you can remove it. '
+                'If you do so, do not forget to increase the woob version to at '
+                'least 3.4 in requirements.txt.',
+                DeprecationWarning,
+            )
+
         self.logger = getLogger(name, parent=logger)
         self.woob = woob
         self.name = name
@@ -331,6 +377,9 @@ class Module(object):
         self.storage.load(self.STORAGE)
 
     def dump_state(self):
+        """
+        Dump module state into storage.
+        """
         if hasattr(self.browser, 'dump_state'):
             self.storage.set('browser_state', self.browser.dump_state())
             self.storage.save()
@@ -350,14 +399,17 @@ class Module(object):
 
     @property
     def weboob(self):
-        # compatibility property for modules that still use this name
-        # TODO remove when not needed any longer
+        """
+        .. deprecated:: 3.4
+           Don't use this attribute, but :attr:`woob` instead.
+        """
+        warnings.warn('Use Module.woob instead.', DeprecationWarning, stacklevel=2)
         return self.woob
 
     _browser = None
 
     @property
-    def browser(self):
+    def browser(self) -> Browser:
         """
         Attribute 'browser'. The browser is created at the first call
         of this attribute, to avoid useless pages access.
@@ -368,14 +420,14 @@ class Module(object):
             self._browser = self.create_default_browser()
         return self._browser
 
-    def create_default_browser(self):
+    def create_default_browser(self) -> Browser | None:
         """
         Method to overload to build the default browser in
         attribute 'browser'.
         """
         return self.create_browser()
 
-    def create_browser(self, *args, **kwargs):
+    def create_browser(self, *args, **kwargs) -> Browser | None:
         """
         Build a browser from the BROWSER class attribute and the
         given arguments.
@@ -412,7 +464,17 @@ class Module(object):
 
         return browser
 
-    def get_proxy(self):
+    def get_proxy(self) -> Dict[str, str]:
+        """
+        Get proxy to use.
+
+        It will read in environment variables, then in backend config.
+
+        Proxy keys in backend config are:
+
+        * ``_proxy`` for HTTP requests
+        * ``_proxy_ssl`` for HTTPS requests
+        """
         # Get proxies from environment variables
         proxies = getproxies()
         # Override them with backend-specific config
@@ -427,21 +489,21 @@ class Module(object):
         return proxies
 
     @classmethod
-    def iter_caps(klass):
+    def iter_caps(cls) -> Iterator[Type[Capability]]:
         """
         Iter capabilities implemented by this backend.
 
         :rtype: iter[:class:`woob.capabilities.base.Capability`]
         """
-        for base in klass.mro():
-            if issubclass(base, Capability) and base != Capability and base != klass and not issubclass(base, Module):
+        for base in cls.mro():
+            if issubclass(base, Capability) and base != Capability and base != cls and not issubclass(base, Module):
                 yield base
 
-    def has_caps(self, *caps):
+    def has_caps(self, *caps) -> bool:
         """
         Check if this backend implements at least one of these capabilities.
 
-        `caps` should be list of capability objects (e.g. CapBank) or capability names (e.g. 'bank').
+        `caps` should be list of :class:`Capability` objects (e.g. :class:`CapBank`) or capability names (e.g. 'bank').
         """
         available_cap_names = [cap.__name__ for cap in self.iter_caps()]
         return any(
@@ -449,7 +511,7 @@ class Module(object):
             for c in caps
         )
 
-    def fillobj(self, obj, fields=None):
+    def fillobj(self, obj: BaseObject, fields: List[str] | None = None):
         """
         Fill an object with the wanted fields.
 
@@ -503,7 +565,7 @@ class Module(object):
 
         for key, value in self.OBJECTS.items():
             if isinstance(obj, key):
-                self.logger.debug(u'Fill %r with fields: %s' % (obj, missing_fields))
+                self.logger.debug('Fill %r with fields: %s', obj, missing_fields)
                 obj = value(self, obj, missing_fields) or obj
                 break
 
@@ -525,6 +587,10 @@ class MetaModule(type):
     # we can remove this class as soon as we get rid of Abstract*
     def __new__(mcs, name, bases, dct):
         if name != 'AbstractModule' and AbstractModule in bases:
+            warnings.warn('AbstractModule is deprecated and will be removed in woob 4.0. '
+                          'Use standard "from woob_modules.other_module import Module" instead.',
+                          DeprecationWarning, stacklevel=2)
+
             module = importlib.import_module('woob_modules.%s' % dct['PARENT'])
             symbols = [getattr(module, attr) for attr in dir(module) if not attr.startswith('__')]
             klass = next(
@@ -538,8 +604,11 @@ class MetaModule(type):
             if additional_config:
                 dct['CONFIG'] = BackendConfig(*(list(klass.CONFIG.values()) + list(additional_config.values())))
 
-        return super(MetaModule, mcs).__new__(mcs, name, bases, dct)
+        return super().__new__(mcs, name, bases, dct)
 
 
 class AbstractModule(metaclass=MetaModule):
-    """Don't use this class, import woob_modules.other_module.etc instead"""
+    """
+    .. deprecated:: 3.4
+       Don't use this class, import woob_modules.other_module.etc instead
+    """
