@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2014 Oleg Plakhotniuk
 #
 # This file is part of woob.
@@ -28,7 +26,7 @@ from tempfile import mkstemp
 __all__ = ['decompress_pdf', 'get_pdf_rows']
 
 
-def decompress_pdf(inpdf):
+def decompress_pdf(inpdf: bytes) -> bytes:
     """
     Takes PDF file contents as a string and returns decompressed version
     of the file contents, suitable for text parsing.
